SystemOrganization addCategory: #VolunteerMPlace!

TestCase subclass: #BrunoTest
	instanceVariableNames: 'coordinator project task coordStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!BrunoTest methodsFor: 'running' stamp: 'BBC 10/3/2012 22:48'!
setUp
	"set up test environment"
	
	coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := VolunteerProject new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 	
			
	task := Task new.	
	task name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. ! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 21:22'!
testCreatingCoordinator
	"comment stating purpose of message"

	| fileName fileStream|
	
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP' ;
				 save.

	
	fileName := '/Users/bruno/Desktop/Volunteers/', (coordinator name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).

				
				
	! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 20:42'!
testCreatingProject
	"comment stating purpose of message"
	
	| fileName fileStream|
	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes' ;
		      save. 

	fileName := '/Users/bruno/Desktop/Volunteers/', (project name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 21:28'!
testCreatingTask
	"comment stating purpose of message"
	
	| fileName fileStream|
	
	task name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40 ; 
		  save. 

	fileName := '/Users/bruno/Desktop/Volunteers/', (task name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 23:50'!
testDependeces
	"comment stating purpose of message"
	
	| firstTask|
	
	firstTask := Task new.
	firstTask name: 'Needed Task'.
	
	task dependsOn: firstTask.
	
	self assert: ((task status) = 'Frozen').
! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 23:03'!
testzCoordProjTask
	"comment stating purpose of message"
	
	| coordFile coordStream volunteerFile volunteerStream taskFile taskStream |
	
	coordinator addCoordinatedProject: project.
	
	project addCoordinator: coordinator ;
	            addTask: task.
	
	task addSkill: 'teaching' ;
		 addVolunteer: 'Isaac Newton'.

	coordinator save.
	project save.
	task save.
	
	coordFile := '/Users/bruno/Desktop/Volunteers/', (coordinator name), '.txt'.
	coordStream := FileStream fileNamed: coordFile.
	volunteerFile := '/Users/bruno/Desktop/Volunteers/', (project name), '.txt'.
	volunteerStream := FileStream fileNamed: volunteerFile.
	taskFile := '/Users/bruno/Desktop/Volunteers/', (task name), '.txt'.
	taskStream := FileStream fileNamed: taskFile.
	
	self deny: (coordStream = nil & volunteerStream = nil & taskStream = nil).! !

Object subclass: #Coordinator
	instanceVariableNames: 'name email organization coordinatedProjects coordinatorCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Coordinator commentStamp: 'BBC 9/22/2012 19:14' prior: 0!
stores a coordinator!

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:32'!
addCoordinatedProject: aProject
	"to set the value of coordinatedProjects"
	
	coordinatedProjects add: aProject.
	coordinatorCollection at: #coordinatedProjects put: coordinatedProjects.

! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
coordinatedProjects
	"get coordinator coordinated projects"

	coordinatedProjects do: [:project | Transcript cr; show: (project name) printString].! !

!Coordinator methodsFor: 'create/remove/edit' stamp: 'BBC 10/3/2012 19:18'!
createProject: projectName
	"creates a new Project"

	| aProject|
	
	"Project Aspects"
	aProject := VolunteerProject new.
	aProject name: projectName.
	aProject addCoordinator: name.
	
	"Coordinator Aspects"
	(coordinatedProjects = nil) 
		ifTrue: [coordinatedProjects := Set with: projectName]
		ifFalse: [coordinatedProjects add: projectName].
			
	"Persistence"
	aProject save.
	
	^ aProject
	

	
	! !

!Coordinator methodsFor: 'create/remove/edit' stamp: 'BBC 10/1/2012 01:06'!
deleteProject: aProject
	"to delete a project"

	| fileName fileOps|
	
	fileName := '/Users/bruno/Desktop/Volunteers/', aProject, '.txt'.
	fileOps := FileDirectory new. 
	fileOps deleteFileNamed: fileName.
	Transcript cr; show: fileName, ' removed.'

	
	

	

	
	! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
email
	"get coordinator email"

	^ email! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:32'!
email: aString
	"to set the value of email"
	
	email := aString.
	coordinatorCollection at: #email put: aString.! !

!Coordinator methodsFor: 'initialize-release' stamp: 'BBC 9/23/2012 14:44'!
initialize
	"Creates a collection to handle coordinator aspects"
	
	coordinatedProjects := Set new.
	coordinatorCollection := Dictionary newFrom: {#name->nil. #email->nil. 												                                                                              #organization->nil.#coordinatedProjects->coordinatedProjects}.
	
! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
name
	"get coordinator name"

	^ name! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:33'!
name: aString
	"to set the value of name"
	
	name := aString.
	coordinatorCollection at: #name put: aString.! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
organization
	"get coordinator organization"

	^ organization! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:33'!
organization: aString
	"to set the value of organization"
	
	organization := aString.
	coordinatorCollection at: #organization put: aString.! !

!Coordinator methodsFor: 'create/remove/edit' stamp: 'BBC 10/3/2012 20:29'!
readProject: projectName
	"to read project args"

	| fileName fileStream line |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', projectName, '.txt'.
	fileStream := FileStream fileNamed: fileName.
	[fileStream atEnd] whileFalse: [line := fileStream nextLine. Transcript cr; show: (line)].
	
	

	

	
	! !

!Coordinator methodsFor: 'persistence' stamp: 'BBC 10/3/2012 23:21'!
save
	"to write a Coordinator into a file"

	| fileName fileStream |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', name, '.txt'.
	fileStream := FileStream forceNewFileNamed: fileName.
	fileStream nextPutAll: 'Name: ', (coordinatorCollection at: #name) printString; cr.
	fileStream nextPutAll: 'Email: ', (coordinatorCollection at: #email) printString; cr.
	fileStream nextPutAll: 'Organization: ', (coordinatorCollection at: #organization) printString; cr.
	fileStream nextPutAll: 'Coordinated Projects: '.
	coordinatedProjects do: [:project | fileStream nextPutAll: (project name) printString].
	fileStream close.
	Transcript cr; show: fileName, ' saved.'! !

Object subclass: #Task
	instanceVariableNames: 'name description status startDate endDate estimatedTime skills volunteers dependsOn'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Task commentStamp: 'BBC 10/2/2012 00:57' prior: 0!
stores a task!

!Task methodsFor: 'as yet unclassified' stamp: 'BBC 10/5/2012 19:33'!
= aTask
	"comment stating purpose of message"

	^ (self name = aTask name)! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:55'!
addSkill: aSkill
	"to set the value of skills"
	
	skills add: aSkill.! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:55'!
addVolunteer: aVolunteer
	"to set the value of volunteers"
	
	volunteers add: aVolunteer.
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 23:13'!
dependsOn
	"get task dependences"

	dependsOn do: [:task | Transcript cr; show: (task name) printString].
! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:55'!
dependsOn: aTask
	"to set task dependences"
	
	 
	dependsOn add: aTask.
	dependsOn do: [:task | ((task status) = 'Open') ifTrue: [self status: 'Frozen'] ].
	! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
description
	"get task description"

	^ description! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
description: aString
	"to set the value of description"
	
	description := aString.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
endDate
	"get task end date"

	^ endDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
endDate: aString
	"to set the value of endDate"
	
	endDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
estimatedTime
	"get task estimated time"

	^ estimatedTime! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
estimatedTime: anInteger
	"to set the value of estimatedTime, in hours"
	
	estimatedTime := anInteger.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/5/2012 19:58'!
hasSkill: aSkill
	"Test if contains a skill"

	^(skills includes: aSkill).
! !

!Task methodsFor: 'initialize-release' stamp: 'BBC 10/5/2012 19:54'!
initialize
	"Creates a collection to handle task aspects"
	
	status := 'Open'.
	startDate := Date today.
	skills := Set new.
	volunteers := Set new.
	dependsOn := Set new.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
name
	"get task name"

	^ name! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
name: aString
	"to set the value of name"
	
	name := aString.! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/3/2012 23:27'!
save
	"to write a Task into a file"

	| fileName fileStream |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', name, '.txt'.
	fileStream := FileStream forceNewFileNamed: fileName.
	fileStream nextPutAll: 'Name: ', (taskCollection at: #name) printString; cr.
	fileStream nextPutAll: 'Description: ', (taskCollection at: #description) printString; cr.
	fileStream nextPutAll: 'Status: ', (taskCollection at: #status) printString; cr.
	fileStream nextPutAll: 'Depends On: '.
	dependsOn do: [:task | fileStream nextPutAll: (task name) printString].
	fileStream nextPutAll: '' ; cr.
	fileStream nextPutAll: 'Start Date: ', (taskCollection at: #startDate) printString; cr.
	fileStream nextPutAll: 'End Date: ', (taskCollection at: #endDate) printString; cr.
	fileStream nextPutAll: 'Estimated Time (hours): ', (taskCollection at: #estimatedTime) printString; cr.	
	fileStream nextPutAll: 'Skills: '.
	"skills do: [:skill | fileStream nextPutAll: (skill name) printString]."
	skills do: [:skill | fileStream nextPutAll: (skill) printString].
	fileStream nextPutAll: '' ; cr.
	fileStream nextPutAll: 'Volunteers: '.
	"volunteers do: [:volunteer | fileStream nextPutAll: (volunteer name) printString]."
	volunteers do: [:volunteer | fileStream nextPutAll: (volunteer) printString].
	fileStream close.
	Transcript cr; show: fileName, ' saved.'! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
skills
	"get task skills"

	skills do: [:skill | Transcript cr; show: (skill name) printString].
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
startDate
	"get task start date"

	^ startDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
startDate: aString
	"to set the value of startDate"
	
	startDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
status
	"get task status"

	^ status! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
status: aString
	"to set the value of status"
	
	status := aString.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
volunteers
	"get task volunteers"

	volunteers do: [:volunteer | Transcript cr; show: (volunteer name) printString].
! !

Object subclass: #TaskCollection
	instanceVariableNames: 'taskCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

TaskCollection class
	instanceVariableNames: 'soleInstance'!

TaskCollection class
	instanceVariableNames: 'soleInstance'!

!TaskCollection class methodsFor: 'instance access' stamp: 'BBC 10/5/2012 19:22'!
default
	"comment stating purpose of message"

	(soleInstance isNil) ifTrue: [soleInstance := self basicNew initialize].
	^ soleInstance! !

!TaskCollection class methodsFor: 'instance creation' stamp: 'BBC 10/5/2012 19:20'!
new
	"comment stating purpose of message"

	self error: 'Cannot implement a new instance.'! !

!TaskCollection class methodsFor: 'reset' stamp: 'BBC 10/5/2012 19:27'!
reset
	"comment stating purpose of message"

	soleInstance := nil.! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/5/2012 19:43'!
addTask: aTask
	"Set the value of taskCollection"

	taskCollection add: aTask.
	Transcript cr ; show: (aTask name), ' added'.! !

!TaskCollection methodsFor: 'initialize-release' stamp: 'BBC 10/5/2012 19:23'!
initialize
	"comment stating purpose of message"

	taskCollection := OrderedCollection new.! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/5/2012 19:52'!
removeTask: aTask
	"Set the value of taskCollection"
	
	| taskIndex |
	
	[taskIndex := (taskCollection find: aTask).
	(taskIndex isNil) ifFalse: [taskCollection removeAt: taskIndex].
	Transcript cr ; show: (aTask name), ' removed']
	on: Exception
	do: [:ex | Transcript cr ; show: 'This task was not created yet.']! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/5/2012 19:47'!
updateTask: aTask
	"Set the value of taskCollection"
	
	
	self removeTask: aTask.
	self addTask: aTask.
	Transcript cr ; show: (aTask name), ' updated'. ! !

Object subclass: #VolunteerProject
	instanceVariableNames: 'name type status description coordinators tasks projectCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!VolunteerProject commentStamp: 'BBC 9/23/2012 11:43' prior: 0!
stores a project!

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:33'!
addCoordinator: aCoordinator
	"to set the value of coordinators"
	
	coordinators add: aCoordinator.
	projectCollection at: #coordinators put: coordinators.
	! !

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:34'!
addTask: aTask
	"to set the value of tasks"
	
	tasks add: aTask.
	projectCollection at: #tasks put: tasks.! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:34'!
coordinators
	"get project coordinators"

	coordinators do: [:coordinator | Transcript cr; show: (coordinator name) printString].! !

!VolunteerProject methodsFor: 'create/remove/edit' stamp: 'BBC 10/2/2012 00:58'!
createTask: taskName
	"creates a new Task"

	| aTask|
	
	"Task Aspects"
	aTask := Task new.
	aTask name: taskName.
	
	"Project Aspects"
	tasks add: aTask.
	
			
	"Persistence"
	aTask save.! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:35'!
description
	"get project description"

	^ description! !

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:34'!
description: aString
	"to set the value of description"
	
	description := aString.
	projectCollection at: #description put: aString.! !

!VolunteerProject methodsFor: 'initialize-release' stamp: 'BBC 10/3/2012 15:35'!
initialize
	"Creates a collection to handle project aspects"
	
	status := 'Open'.
	coordinators := Set new.
	tasks := Set new.
	projectCollection := Dictionary newFrom: {#name->nil. #description->nil. #type->nil. #status->status. 
											     #coordinators->nil. #tasks->nil}.
	! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:35'!
name
	"get project name"
	
	^ name! !

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:34'!
name: aString
	"to set the value of name"
	
	name := aString.
	projectCollection at: #name put: aString.! !

!VolunteerProject methodsFor: 'persistence' stamp: 'BBC 10/5/2012 18:22'!
save
	"to write a Project into a file"

	| fileName fileStream |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', name, '.txt'.
	fileStream := FileStream forceNewFileNamed: fileName.
	fileStream nextPutAll: 'Name: ', (projectCollection at: #name) printString; cr.
	fileStream nextPutAll: 'Description: ', (projectCollection at: #description) printString; cr.
	fileStream nextPutAll: 'Type: ', (projectCollection at: #type) printString; cr.
	fileStream nextPutAll: 'Status: ', (projectCollection at: #status) printString; cr.
	fileStream nextPutAll: 'Coordinators: '.
	coordinators do: [:coordinator | fileStream nextPutAll: (coordinator name) printString].
	fileStream nextPutAll: '' ; cr.
	fileStream nextPutAll: 'Tasks: '.
	tasks do: [:task | fileStream nextPutAll: (task name) printString].
	fileStream close.
	Transcript cr; show: fileName, ' saved.'.
	
	 Smalltalk snapshot: true andQuit: false. Transcript cr; show:'Snapshot Taken!!'
! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:35'!
status
	"get project status"

	^ status! !

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:34'!
status: aString
	"to set the value of status"
	
	status := aString.
	projectCollection at: #status put: aString.! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:35'!
tasks
	"get project tasks"

	tasks do: [:task | Transcript cr; show: (task name) printString].! !

!VolunteerProject methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:35'!
type
	"get project type"

	^ type! !

!VolunteerProject methodsFor: 'sets' stamp: 'BBC 10/3/2012 15:34'!
type: aString
	"to set the value of type"
	
	type := aString.
	projectCollection at: #type put: aString.! !
